@@ -2,8 +2,8 @@
   var map = {
   "css": [],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.a802c628.js",
-    "@zoom/client-scheduler/static/js/app.c6488505.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.f26129e8.js",
+    "@zoom/client-scheduler/static/js/index.bfe2ce09.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
